PCAP API
========

Most operations can be performed with the :py:class`PcapFile` class.
The public methods are as follows:


.. automodule:: steelscript.wireshark.core

.. currentmodule:: steelscript.wireshark.core.pcap


:py:class:`PcapFile` Objects
-------------------------------

.. autoclass:: PcapFile
   :members:

